@@ -1,38 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2017 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
-**
-** This file is part of the QtSerialBus module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL3$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPLv3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or later as published by the Free
-** Software Foundation and appearing in the file LICENSE.GPL included in
-** the packaging of this file. Please review the following information to
-** ensure the GNU General Public License version 2.0 requirements will be
-** met: http://www.gnu.org/licenses/gpl-2.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2017 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #include "qmodbusclient.h"
 #include "qmodbusclient_p.h"
@@ -129,7 +96,7 @@ QModbusReply *QModbusClient::sendReadWriteRequest(const QModbusDataUnit &read,
     fits inside the Modbus PDU data section and has a valid function code.
     The only check performed before sending is therefore the validity check,
     see \l QModbusPdu::isValid. If no error occurred the function returns a
-    a new valid \l QModbusReply; nullptr otherwise. Modbus networks may have
+    new valid \l QModbusReply; nullptr otherwise. Modbus networks may have
     multiple servers, each server has a unique \a serverAddress.
 
     \sa QModbusReply::rawResult()
@@ -219,8 +186,12 @@ QModbusClient::QModbusClient(QModbusClientPrivate &dd, QObject *parent) :
 }
 
 /*!
-    Processes a Modbus server \a response and stores the decoded information in \a data. Returns
-    true on success; otherwise false.
+    Processes a Modbus server \a response and stores the decoded information in
+    \a data. Returns \c true on success; otherwise \c false.
+
+    \note The default implementation does not support all
+    \l {QModbusPdu::}{FunctionCode}s. Override this method in a custom Modbus
+    client implementations to handle the needed functions.
 */
 bool QModbusClient::processResponse(const QModbusResponse &response, QModbusDataUnit *data)
 {
@@ -364,8 +335,8 @@ void QModbusClientPrivate::processQueueElement(const QModbusResponse &pdu,
     }
 
     QModbusDataUnit unit = element.unit;
-    if (!processResponse(pdu, &unit)) {
-        element.reply->setError(QModbusDevice::UnknownError,
+    if (!q_func()->processResponse(pdu, &unit)) {
+        element.reply->setError(QModbusDevice::InvalidResponseError,
             QModbusClient::tr("An invalid response has been received."));
         return;
     }
